@@ -3,7 +3,8 @@
 # if successfully confirmed by any service - no more services
 # are checked.
 Set($ExternalAuthPriority,  [   'My_LDAP',
-                                'My_MySQL'
+                                'My_MySQL',
+                                'My_SSO_Cookie'
                             ]
 );
 
@@ -11,7 +12,10 @@ Set($ExternalAuthPriority,  [   'My_LDAP',
 # should be used to get information about users. This includes
 # RealName, Tel numbers etc, but also whether or not the user
 # should be considered disabled. 
+#
 # Once user info is found, no more services are checked.
+#
+# You CANNOT use a SSO cookie for authentication.
 Set($ExternalInfoPriority,  [   'My_MySQL',
                                 'My_LDAP'
                             ]
@@ -31,16 +35,12 @@ Set($AutoCreateNonExternalUsers,    0);
 # Note that you may have as many external services as you wish. They will
 # be checked in the order specified in the Priority directives above.
 # e.g. 
-#   Set(ExternalAuthPriority,['My_LDAP','My_MySQL','My_Oracle','SecondaryLDAP','Other-DB']);
+#   Set($ExternalAuthPriority,['My_LDAP','My_MySQL','My_Oracle','SecondaryLDAP','Other-DB']);
 #
 Set($ExternalSettings,      {   # AN EXAMPLE DB SERVICE
                                 'My_MySQL'   =>  {      ## GENERIC SECTION
-                                                        # The type of service (db/ldap) 
+                                                        # The type of service (db/ldap/cookie) 
                                                         'type'                      =>  'db',
-                                                        # Should the service be used for authentication?
-                                                        'auth'                      =>  1,
-                                                        # Should the service be used for information?
-                                                        'info'                      =>  1,
                                                         # The server hosting the service
                                                         'server'                    =>  'server.domain.tld',
                                                         ## SERVICE-SPECIFIC SECTION
@@ -64,16 +64,20 @@ Set($ExternalSettings,      {   # AN EXAMPLE DB SERVICE
                                                         # e.g. if the passwords are stored using the MySQL v3.23 "PASSWORD"
                                                         # function, then you will need Crypt::MySQL::password, but for the
                                                         # MySQL4+ password function you will need Crypt::MySQL::password41
-                                                        # Alternatively, you could use Crypt::MD5::md5_hex or any other
+                                                        # Alternatively, you could use Digest::MD5::md5_hex or any other
                                                         # encryption subroutine you can load in your perl installation
                                                         'p_enc_pkg'                 =>  'Crypt::MySQL',
                                                         'p_enc_sub'                 =>  'password',
+                                                        # If your p_enc_sub takes a salt as a second parameter, 
+                                                        # uncomment this line to add your salt
+                                                        #'p_salt'                    =>  'SALT',
+                                                        #
                                                         # The field and values in the table that determines if a user should
                                                         # be disabled. For example, if the field is 'user_status' and the values
                                                         # are ['0','1','2','disabled'] then the user will be disabled if their
                                                         # user_status is set to '0','1','2' or the string 'disabled'.
                                                         # Otherwise, they will be considered enabled.
-                                                        'd_field'                   =>  'userSupportAccess',
+                                                        'd_field'                   =>  'disabled',
                                                         'd_values'                  =>  ['0'],
                                                         ## RT ATTRIBUTE MATCHING SECTION
                                                         # The list of RT attributes that uniquely identify a user
@@ -91,10 +95,6 @@ Set($ExternalSettings,      {   # AN EXAMPLE DB SERVICE
                                 'My_LDAP'       =>  {   ## GENERIC SECTION
                                                         # The type of service (db/ldap/cookie) 
                                                         'type'                      =>  'ldap',
-                                                        # Should the service be used for authentication?
-                                                        'auth'                      =>  1,
-                                                        # Should the service be used for information?
-                                                        'info'                      =>  1,
                                                         # The server hosting the service
                                                         'server'                    =>  'server.domain.tld',
                                                         ## SERVICE-SPECIFIC SECTION
@@ -122,12 +122,16 @@ Set($ExternalSettings,      {   # AN EXAMPLE DB SERVICE
                                                         #
                                                         # Should we try to use TLS to encrypt connections?
                                                         'tls'                       =>  0,
+                                                        # SSL Version to provide to Net::SSLeay *if* using SSL
+                                                        'ssl_version'               =>  3,
                                                         # What other args should I pass to Net::LDAP->new($host,@args)?
                                                         'net_ldap_args'             => [    version =>  3   ],
                                                         # Does authentication depend on group membership? What group name?
                                                         'group'                     =>  'GROUP_NAME',
                                                         # What is the attribute for the group object that determines membership?
                                                         'group_attr'                =>  'GROUP_ATTR',
+                                                        # What is the attribute of the user entry that should be matched against group_attr above? (Optional; defaults to 'dn')
+                                                        'group_attr_value'          =>  'GROUP_ATTR_VALUE',
                                                         ## RT ATTRIBUTE MATCHING SECTION
                                                         # The list of RT attributes that uniquely identify a user
 							# This example shows what you *can* specify.. I recommend reducing this
@@ -152,6 +156,28 @@ Set($ExternalSettings,      {   # AN EXAMPLE DB SERVICE
                                                                                             'Zip' => 'postalCode',
                                                                                             'Country' => 'co'
                                                                                         }
+                                                    },
+                                # An example SSO cookie service
+                                'My_SSO_Cookie'  => {   # # The type of service (db/ldap/cookie)
+                                                        'type'                      =>  'cookie',
+                                                        # The name of the cookie to be used
+                                                        'name'                      =>  'loginCookieValue',
+                                                        # The users table
+                                                        'u_table'                   =>  'users',
+                                                        # The username field in the users table
+                                                        'u_field'                   =>  'username',
+                                                        # The field in the users table that uniquely identifies a user
+                                                        # and also exists in the cookies table
+                                                        'u_match_key'               =>  'userID',
+                                                        # The cookies table
+                                                        'c_table'                   =>  'login_cookie',
+                                                        # The field that stores cookie values
+                                                        'c_field'                   =>  'loginCookieValue',
+                                                        # The field in the cookies table that uniquely identifies a user
+                                                        # and also exists in the users table
+                                                        'c_match_key'               =>  'loginCookieUserID',
+                                                        # The DB service in this configuration to use to lookup the cookie information
+                                                        'db_service_name'           =>  'My_MySQL'
                                                     }
                                 }
 );
